@@ -202,14 +202,14 @@ def run_command(cf, method, command, params=None, content=None, files=None):
             if len(e) > 0:
                 # more than one error returned by the API
                 for x in e:
-                    sys.stderr.write('cli4: /%s - %d %s\n' % (command, x, x))
-            sys.stderr.write('cli4: /%s - %d %s\n' % (command, e, e))
+                    sys.stderr.write('cli4: /%s - %d %s\n' % (command, int(x), str(x)))
+            sys.stderr.write('cli4: /%s - %d %s\n' % (command, int(e), str(e)))
             raise e
         except CloudFlare.exceptions.CloudFlareInternalError as e:
-            sys.stderr.write('cli4: InternalError: /%s - %d %s\n' % (command, e, e))
+            sys.stderr.write('cli4: InternalError: /%s - %d %s\n' % (command, int(e), str(e)))
             raise e
         except Exception as e:
-            sys.stderr.write('cli4: /%s - %s - api error\n' % (command, e))
+            sys.stderr.write('cli4: /%s - %s - api error\n' % (command, str(e)))
             raise e
 
         results.append(r)
@@ -239,7 +239,7 @@ def write_results(results, output):
                                      sort_keys=True,
                                      ensure_ascii=False,
                                      encoding='utf8')
-            except TypeError as e:
+            except TypeError:
                 results = json.dumps(results,
                                      indent=4,
                                      sort_keys=True,
@@ -272,6 +272,7 @@ def do_it(args):
     raw = False
     dump = False
     dump_from_web = False
+    binary_file = False
     profile = None
     method = 'GET'
 
@@ -281,6 +282,7 @@ def do_it(args):
              + '[-r|--raw] '
              + '[-d|--dump] '
              + '[-a|--api] '
+             + '[-b|--binary] '
              + '[-p|--profile profile-name] '
              + '[--get|--patch|--post|--put|--delete] '
              + '[item=value|item=@filename|@filename ...] '
@@ -288,12 +290,13 @@ def do_it(args):
 
     try:
         opts, args = getopt.getopt(args,
-                                   'Vhvqjyrdap:GPOUD',
+                                   'Vhvqjyrdabp:GPOUD',
                                    [
                                        'version',
                                        'help', 'verbose', 'quiet', 'json', 'yaml', 'ndjson',
                                        'raw',
                                        'dump', 'api',
+                                       'binary',
                                        'profile=',
                                        'get', 'patch', 'post', 'put', 'delete'
                                    ])
@@ -326,6 +329,8 @@ def do_it(args):
             dump = True
         elif opt in ('-a', '--api'):
             dump_from_web = True
+        elif opt in ('-b', '--binary'):
+            binary_file = True
         elif opt in ('-G', '--get'):
             method = 'GET'
         elif opt in ('-P', '--patch'):
@@ -363,10 +368,17 @@ def do_it(args):
                 sys.exit('cli4: %s - raw file upload only with PUT or POST' % (filename))
             try:
                 if filename == '-':
-                    content = sys.stdin.read()
+                    if binary_file:
+                        content = sys.stdin.buffer.read()
+                    else:
+                        content = sys.stdin.read()
                 else:
-                    with open(filename, 'r') as f:
-                        content = f.read()
+                    if binary_file:
+                        with open(filename, 'rb') as f:
+                            content = f.read()
+                    else:
+                        with open(filename, 'r') as f:
+                            content = f.read()
             except IOError:
                 sys.exit('cli4: %s - file open failure' % (filename))
             continue
@@ -442,6 +454,7 @@ def do_it(args):
     except Exception as e:
         sys.exit(e)
 
+    exit_with_error = False
     for command in commands:
         try:
             results = run_command(cf, method, command, params, content, files)
@@ -449,8 +462,10 @@ def do_it(args):
         except KeyboardInterrupt as e:
             sys.exit('cli4: %s - Interrupted\n' % (command))
         except Exception as e:
-            if len(commands) > 1:
-                continue
+            exit_with_error = True
+
+    if exit_with_error:
+        sys.exit(1)
 
 def cli4(args):
     """Cloudflare API via command line"""
